# -*- encoding: utf-8 -*-
# rebookmaker v0.8.1
# EPUB generator
# Copyright © 2020, Shlomi Fish.
# See /LICENSE for licensing information.

"""
INSERT MODULE DESCRIPTION HERE.

:Copyright: © 2020, Shlomi Fish.
:License: BSD (see /LICENSE).
"""

__all__ = ()
